@@ -113,18 +113,18 @@ def _writeParamField(componentOption, NewParamValueDictionary, hubName):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		parmString = json.dumps(NewParamValueDictionary)
 		sql = "UPDATE jos_extensions set params = %s WHERE type='component' AND `element` = %s AND client_id=1"
-	else:
+		data = (parmString, componentOption)
+		db.query_rowcount(sql, data)
+	except:
 		parmString = ""
 		for parm in NewParamValueDictionary:
 			parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
 		sql = "UPDATE jos_components set params = %s WHERE `option` = %s"
-
-
-	data = (parmString, componentOption)
-	db.query_rowcount(sql, data)
+		data = (parmString, componentOption)
+		db.query_rowcount(sql, data)
 
 
 def _writePluginParamField(folder, element, NewParamValueDictionary, hubName):
@@ -138,17 +138,18 @@ def _writePluginParamField(folder, element, NewParamValueDictionary, hubName):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		parmString = json.dumps(NewParamValueDictionary)
 		sql = "UPDATE `jos_extensions` SET `params`=%s WHERE `type`='plugin' AND `folder`=%s AND `element`=%s"
-	else:
+		data = (parmString, folder, element)
+		db.query_rowcount(sql, data)
+	except:
 		parmString = ""
 		for parm in NewParamValueDictionary:
 			parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
 		sql = "UPDATE `jos_plugins` SET `params`=%s WHERE `folder`=%s AND `element`=%s"
-
-	data = (parmString, folder, element)
-	db.query_rowcount(sql, data)
+		data = (parmString, folder, element)
+		db.query_rowcount(sql, data)
 
 
 def _writeModuleParamField(module, NewParamValueDictionary, hubName):
@@ -162,17 +163,18 @@ def _writeModuleParamField(module, NewParamValueDictionary, hubName):
         dbName = getWebConfigDBName(hubName)
         db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-        if hubzero.utilities.misc.JOOMLA_25:
+        try:
                 parmString = json.dumps(NewParamValueDictionary)
                 sql = "UPDATE `jos_modules` SET `params`=%s WHERE `title`=%s"
-        else:
+	        data = (parmString, module)
+        	db.query_rowcount(sql, data)
+        except:
                 parmString = ""
                 for parm in NewParamValueDictionary:
                         parmString += parm + "=" + NewParamValueDictionary[parm] + "\n"
                 sql = "UPDATE `jos_modules` SET `params`=%s WHERE `title`=%s"
-
-        data = (parmString, module)
-        db.query_rowcount(sql, data)
+	        data = (parmString, module)
+        	db.query_rowcount(sql, data)
 
 
 def _writeTemplateParamField(template, NewParamValueDictionary, hubName):
@@ -186,16 +188,13 @@ def _writeTemplateParamField(template, NewParamValueDictionary, hubName):
         dbName = getWebConfigDBName(hubName)
         db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-        if hubzero.utilities.misc.JOOMLA_25:
+        try:
                 parmString = json.dumps(NewParamValueDictionary)
                 sql = "UPDATE `jos_template_styles` SET `params`=%s WHERE `template`=%s"
-        else:
-		raise Exception
-
-        data = (parmString, template)
-        db.query_rowcount(sql, data)
-
-
+        	data = (parmString, template)
+      		  db.query_rowcount(sql, data)
+        except:
+		pass
 
 def _buildDictionary(componentOption, hubName):
 	"""
@@ -215,18 +214,19 @@ def _buildDictionary(componentOption, hubName):
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		sql = "SELECT `params` from jos_extensions WHERE type='component' AND `element`=%s AND client_id=1"
-	else:
+		data = (componentOption)
+		paramsString = db.query_selectscalar(sql, data)
+	except:
 		sql = "SELECT `params` from jos_components WHERE `option`=%s"
-
-	data = (componentOption)
-	paramsString = db.query_selectscalar(sql, data)
+		data = (componentOption)
+		paramsString = db.query_selectscalar(sql, data)
 
 	if paramsString is None:
 		return {}
 	
-	if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+	if paramsString.startswith('{'):
 		try:
 			parmsDict = json.loads(paramsString)
 			return parmsDict
@@ -260,15 +260,17 @@ def _buildPluginDictionary(folder, element, hubName):
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		sql = "SELECT `params` from jos_extensions WHERE type='plugin' AND folder=%s AND element=%s"
-	else:
+		data = (folder,element)
+		paramsString = db.query_selectscalar(sql, data)
+	except:
 		sql = "SELECT `params` from jos_plugins WHERE `folder`=%s AND `element`=%s"
+		data = (folder,element)
+		paramsString = db.query_selectscalar(sql, data)
 
-	data = (folder,element)
-	paramsString = db.query_selectscalar(sql, data)
 
-	if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+	if paramsString.startswith('{'):
 		try:
 			parmsDict = json.loads(paramsString)
 			return parmsDict
@@ -309,7 +311,7 @@ def _buildModuleDictionary(module, hubName):
         data = (module)
         paramsString = db.query_selectscalar(sql, data)
 
-        if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+        if paramsString.startswith('{'):
                 try:
                         parmsDict = json.loads(paramsString)
                         return parmsDict
@@ -350,7 +352,7 @@ def _buildTemplateDictionary(template, hubName):
         data = (template)
         paramsString = db.query_selectscalar(sql,template)
 
-        if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+        if paramsString.startswith('{'):
                 try:
                         parmsDict = json.loads(paramsString)
                         return parmsDict
@@ -489,12 +491,14 @@ def setPluginEnabled(pluginFolder, pluginElement, enable, hubName = ""):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		sql = "UPDATE jos_extensions set enabled = %s WHERE type='plugin' AND `folder` = %s AND `element` = %s"
-	else:
+		data = (enable, pluginFolder, pluginElement)
+		db.query_rowcount(sql, data)	
+	except:
 		sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
-	data = (enable, pluginFolder, pluginElement)
-	db.query_rowcount(sql, data)	
+		data = (enable, pluginFolder, pluginElement)
+		db.query_rowcount(sql, data)	
 
 
 def getPluginEnabled(pluginFolder, pluginElement, hubName = ""):
@@ -508,12 +512,15 @@ def getPluginEnabled(pluginFolder, pluginElement, hubName = ""):
 	dbName = getWebConfigDBName(hubName)	
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 		
-	if hubzero.utilities.misc.JOOMLA_25:
+	try:
 		sql = "SELECT enabled FROM jos_extensions  WHERE type='plugins' AND `folder` = %s AND `element` = %s"
-	else:
+		data = (pluginFolder, pluginElement)
+		published = db.query_selectscalar(sql, data)
+	except:
 		sql = "SELECT published FROM jos_plugins WHERE `folder` = %s AND `element` = %s"
-	data = (pluginFolder, pluginElement)
-	published = db.query_selectscalar(sql, data)
+		data = (pluginFolder, pluginElement)
+		published = db.query_selectscalar(sql, data)
+
 	return published
 
 
